==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/id.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'id', {
	button: {
		title: 'Button Properties', // MISSING
		text: 'Teks (Nilai)',
		type: 'Tipe',
		typeBtn: 'Tombol',
		typeSbm: 'Menyerahkan',
		typeRst: 'Reset' // MISSING
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox Properties', // MISSING
		radioTitle: 'Radio Button Properties', // MISSING
		value: 'Nilai',
		selected: 'Terpilih'
	},
	form: {
		title: 'Form Properties', // MISSING
		menu: 'Form Properties', // MISSING
		action: 'Aksi',
		method: 'Metode',
		encoding: 'Encoding' // MISSING
	},
	hidden: {
		title: 'Hidden Field Properties', // MISSING
		name: 'Nama',
		value: 'Nilai'
	},
	select: {
		title: 'Selection Field Properties', // MISSING
		selectInfo: 'Select Info', // MISSING
		opAvail: 'Available Options', // MISSING
		value: 'Nilai',
		size: 'Ukuran',
		lines: 'garis',
		chkMulti: 'Izinkan pemilihan ganda',
		opText: 'Teks',
		opValue: 'Nilai',
		btnAdd: 'Tambah',
		btnModify: 'Modifikasi',
		btnUp: 'Atas',
		btnDown: 'Bawah',
		btnSetValue: 'Set as selected value', // MISSING
		btnDelete: 'Hapus'
	},
	textarea: {
		title: 'Textarea Properties', // MISSING
		cols: 'Kolom',
		rows: 'Baris'
	},
	textfield: {
		title: 'Text Field Properties', // MISSING
		name: 'Name',
		value: 'Nilai',
		charWidth: 'Character Width', // MISSING
		maxChars: 'Maximum Characters', // MISSING
		type: 'Tipe',
		typeText: 'Teks',
		typePass: 'Kata kunci',
		typeEmail: 'Surel',
		typeSearch: 'Cari',
		typeTel: 'Nomor Telepon',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/id.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'id', {
	button: {
		title: 'Properti Tombol',
		text: 'Teks (Nilai)',
		type: 'Tipe',
		typeBtn: 'Tombol',
		typeSbm: 'Menyerahkan',
		typeRst: 'Atur Ulang'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox Properties', // MISSING
		radioTitle: 'Radio Button Properties', // MISSING
		value: 'Nilai',
		selected: 'Terpilih',
		required: 'Wajib'
	},
	form: {
		title: 'Form Properties', // MISSING
		menu: 'Form Properties', // MISSING
		action: 'Aksi',
		method: 'Metode',
		encoding: 'Encoding' // MISSING
	},
	hidden: {
		title: 'Hidden Field Properties', // MISSING
		name: 'Nama',
		value: 'Nilai'
	},
	select: {
		title: 'Selection Field Properties', // MISSING
		selectInfo: 'Select Info', // MISSING
		opAvail: 'Available Options', // MISSING
		value: 'Nilai',
		size: 'Ukuran',
		lines: 'garis',
		chkMulti: 'Izinkan pemilihan ganda',
		required: 'Wajib',
		opText: 'Teks',
		opValue: 'Nilai',
		btnAdd: 'Tambah',
		btnModify: 'Modifikasi',
		btnUp: 'Atas',
		btnDown: 'Bawah',
		btnSetValue: 'Atur sebagai nilai yang dipilih',
		btnDelete: 'Hapus'
	},
	textarea: {
		title: 'Textarea Properties', // MISSING
		cols: 'Kolom',
		rows: 'Baris'
	},
	textfield: {
		title: 'Text Field Properties', // MISSING
		name: 'Name',
		value: 'Nilai',
		charWidth: 'Character Width', // MISSING
		maxChars: 'Maximum Characters', // MISSING
		required: 'Wajib',
		type: 'Tipe',
		typeText: 'Teks',
		typePass: 'Kata kunci',
		typeEmail: 'Surel',
		typeSearch: 'Cari',
		typeTel: 'Nomor Telepon',
		typeUrl: 'URL'
	}
} );
